@@ -8,7 +8,11 @@ from netmiko.cisco.cisco_ios import CiscoIosFileTransfer
 from netmiko.cisco.cisco_ios import InLineTransfer
 from netmiko.cisco.cisco_asa_ssh import CiscoAsaSSH, CiscoAsaFileTransfer
 from netmiko.cisco.cisco_ftd_ssh import CiscoFtdSSH
-from netmiko.cisco.cisco_nxos_ssh import CiscoNxosSSH, CiscoNxosFileTransfer
+from netmiko.cisco.cisco_nxos import (
+    CiscoNxosSSH,
+    CiscoNxosFileTransfer,
+    CiscoNxosTelnet,
+)
 from netmiko.cisco.cisco_xr import CiscoXrSSH, CiscoXrTelnet, CiscoXrFileTransfer
 from netmiko.cisco.cisco_wlc_ssh import CiscoWlcSSH
 from netmiko.cisco.cisco_s200 import CiscoS200SSH
@@ -25,6 +29,7 @@ __all__ = [
     "CiscoAsaSSH",
     "CiscoFtdSSH",
     "CiscoNxosSSH",
+    "CiscoNxosTelnet",
     "CiscoXrSSH",
     "CiscoXrTelnet",
     "CiscoWlcSSH",
