@@ -2,7 +2,7 @@ from netmiko.dell.dell_dnos6 import DellDNOS6SSH
 from netmiko.dell.dell_dnos6 import DellDNOS6Telnet
 from netmiko.dell.dell_force10_ssh import DellForce10SSH
 from netmiko.dell.dell_os10_ssh import DellOS10SSH, DellOS10FileTransfer
-from netmiko.dell.dell_sonic_ssh import DellSonicSSH
+from netmiko.dell.dell_sonic_ssh import DellSonicSSH, DellSonicFileTransfer
 from netmiko.dell.dell_powerconnect import DellPowerConnectSSH
 from netmiko.dell.dell_powerconnect import DellPowerConnectTelnet
 from netmiko.dell.dell_isilon_ssh import DellIsilonSSH
@@ -14,6 +14,7 @@ __all__ = [
     "DellOS10SSH",
     "DellSonicSSH",
     "DellOS10FileTransfer",
+    "DellSonicFileTransfer",
     "DellIsilonSSH",
     "DellDNOS6SSH",
     "DellDNOS6Telnet",
