@@ -1,3 +1,3 @@
 from netmiko.enterasys.enterasys_ssh import EnterasysSSH
 
-__all__ = ['EnterasysSSH']
+__all__ = ["EnterasysSSH"]
