@@ -8,17 +8,19 @@ class JuniperScreenOsSSH(NoEnable, NoConfig, BaseConnection):
     Implement methods for interacting with Juniper ScreenOS devices.
     """
 
+    def _try_session_preparation(self, force_data: bool = False) -> None:
+        return super()._try_session_preparation(force_data=force_data)
+
     def session_preparation(self) -> None:
         """
         ScreenOS can be configured to require: Accept this agreement y/[n]
         """
         terminator = r"\->"
-        pattern = rf"(Accept this|{terminator})"
-        data = self._test_channel_read(pattern=pattern)
+        pattern = rf"(?:Accept this.*|{terminator})"
+        data = self.read_until_pattern(pattern=pattern)
         if "Accept this" in data:
             self.write_channel("y")
-            data += self._test_channel_read(pattern=terminator)
-
+            data += self.read_until_pattern(pattern=terminator)
         self.set_base_prompt()
         self.disable_paging(command="set console page 0")
 
