@@ -21,7 +21,7 @@ class MrvLxSSH(CiscoSSHConnection):
         self.clear_buffer()
 
     def check_enable_mode(self, check_string: str = ">>") -> bool:
-        """MRV has a >> for enable mode instead of # like Cisco"""
+        """MRV has a >> for enable mode and config mode instead of # like Cisco"""
         return super().check_enable_mode(check_string=check_string)
 
     def enable(
@@ -41,6 +41,26 @@ class MrvLxSSH(CiscoSSHConnection):
             re_flags=re_flags,
         )
 
+    def check_config_mode(
+        self,
+        check_string: str = r"Conf.*>>",
+        pattern: str = "",
+        force_regex: bool = True,
+    ) -> bool:
+        return super().check_config_mode(
+            check_string=check_string, pattern=pattern, force_regex=force_regex
+        )
+
+    def config_mode(
+        self,
+        config_command: str = "configuration",
+        pattern: str = "",
+        re_flags: int = 0,
+    ) -> str:
+        return super().config_mode(
+            config_command=config_command, pattern=pattern, re_flags=re_flags
+        )
+
     def save_config(
         self,
         cmd: str = "save config flash",
