@@ -105,7 +105,7 @@ class NokiaSrlSSH(BaseConnection, NoEnable):
 
     def check_config_mode(
         self,
-        check_string: str = r"\n--{( | \* | \+ | \+\* | \!\+ | \!\* )candidate",
+        check_string: str = r"\n--{( | \* | \+ | \+\* | \!\+ | \!\* | \+\!\* | \+\! )candidate",
         pattern: str = r"#",
         force_regex: bool = True,
     ) -> bool:
@@ -187,5 +187,7 @@ class NokiaSrlSSH(BaseConnection, NoEnable):
         The exclamation mark (!) in the prompt indicates that another user has commited
         changes to the running datastore.
         """
-        matches = re.search(r"\n--{( | \* | \+ | \+\* | \!\+ | \!\* )candidate", prompt)
+        matches = re.search(
+            r"\n--{( | \* | \+ | \+\* | \!\+ | \!\* | \+\!\* | \+\! )candidate", prompt
+        )
         return True if matches and "*" in matches.group() else False
