@@ -83,12 +83,24 @@ SSH_MAPPER_DICT = {
         "priority": 99,
         "dispatch": "_autodetect_std",
     },
+    "aruba_aoscx": {
+        "cmd": "show version",
+        "search_patterns": [r"ArubaOS-CX"],
+        "priority": 99,
+        "dispatch": "_autodetect_std",
+    },
     "ciena_saos": {
         "cmd": "software show",
         "search_patterns": [r"saos"],
         "priority": 99,
         "dispatch": "_autodetect_std",
     },
+    "ciena_waveserver": {
+        "cmd": "software show",
+        "search_patterns": [r"WAVESERVER"],
+        "priority": 99,
+        "dispatch": "_autodetect_std",
+    },
     "cisco_asa": {
         "cmd": "show version",
         "search_patterns": [r"Cisco Adaptive Security Appliance", r"Cisco ASA"],
@@ -134,6 +146,12 @@ SSH_MAPPER_DICT = {
         "priority": 99,
         "dispatch": "_autodetect_std",
     },
+    "cumulus_linux": {
+        "cmd": "uname -a",
+        "search_patterns": [r"Linux cumulus"],
+        "priority": 99,
+        "dispatch": "_autodetect_std",
+    },
     "dell_force10": {
         "cmd": "show version",
         "search_patterns": [r"Real Time Operating System Software"],
@@ -143,15 +161,19 @@ SSH_MAPPER_DICT = {
     "dell_os9": {
         "cmd": "show system",
         "search_patterns": [
-            r"Dell Application Software Version:  9",
-            r"Dell Networking OS Version : 9",
+            r"Dell Application Software Version\s*:\s*9",
+            r"Dell Networking OS Version\s*:\s*9",
+            r"Dell EMC Networking OS Version\s*:\s*9",
         ],
         "priority": 99,
         "dispatch": "_autodetect_std",
     },
     "dell_os10": {
         "cmd": "show version",
-        "search_patterns": [r"Dell EMC Networking OS10.Enterprise"],
+        "search_patterns": [
+            r"Dell EMC Networking OS10.Enterprise",
+            r"Dell SmartFabric OS10[\s*|-]Enterprise",
+        ],
         "priority": 99,
         "dispatch": "_autodetect_std",
     },
@@ -173,6 +195,12 @@ SSH_MAPPER_DICT = {
         "priority": 99,
         "dispatch": "_autodetect_std",
     },
+    "h3c_comware": {
+        "cmd": "display version",
+        "search_patterns": ["H3C Comware Software"],
+        "priority": 99,
+        "dispatch": "_autodetect_std",
+    },
     "hp_comware": {
         "cmd": "display version",
         "search_patterns": ["HPE Comware", "HP Comware"],
@@ -208,7 +236,7 @@ SSH_MAPPER_DICT = {
     "linux": {
         "cmd": "uname -a",
         "search_patterns": [r"Linux"],
-        "priority": 99,
+        "priority": 95,
         "dispatch": "_autodetect_std",
     },
     "ericsson_ipos": {
@@ -219,7 +247,7 @@ SSH_MAPPER_DICT = {
     },
     "extreme_exos": {
         "cmd": "show version",
-        "search_patterns": [r"ExtremeXOS"],
+        "search_patterns": [r"ExtremeXOS", "EXOS"],
         "priority": 99,
         "dispatch": "_autodetect_std",
     },
@@ -315,6 +343,35 @@ SSH_MAPPER_DICT = {
         "priority": 99,
         "dispatch": "_autodetect_std",
     },
+    "huawei_smartax": {
+        "cmd": "display version",
+        "search_patterns": [r"Huawei Integrated Access Software"],
+        "priority": 99,
+        "dispatch": "_autodetect_std",
+    },
+    "nec_ix": {
+        "cmd": "show hardware",
+        "search_patterns": [r"IX Series"],
+        "priority": 99,
+        "dispatch": "_autodetect_std",
+    },
+    "fiberstore_fsosv2": {
+        "cmd": "show version",
+        "search_patterns": [
+            (
+                r"Fiberstore Co., Limited Internetwork Operating System "
+                r"Software[\s\S]*Version 2.[0-9]*.[0-9]*[\s\S]*"
+            )
+        ],
+        "priority": 99,
+        "dispatch": "_autodetect_std",
+    },
+    "telcosystems_binos": {
+        "cmd": "show version",
+        "search_patterns": [r"BiNOS"],
+        "priority": 99,
+        "dispatch": "_autodetect_std",
+    },
 }
 
 # Sort SSH_MAPPER_DICT such that the most common commands are first
@@ -537,6 +594,7 @@ class SSHDetect(object):
             r"command not found",
             r"Syntax Error: unexpected argument",
             r"% Unrecognized command found at",
+            r"% Unknown command, the error locates at",
         ]
         if not cmd or not search_patterns:
             return 0
